==> openshift-model-storageversionmigrator-5.10.2-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StorageStateSpecFluentImpl<A extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent<A>{
  public StorageStateSpecFluentImpl() {
  }
  public StorageStateSpecFluentImpl(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpec instance) {
    this.withResource(instance.getResource()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder resource;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource getResource() {
    return this.resource!=null?this.resource.build():null;
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource buildResource() {
    return this.resource!=null?this.resource.build():null;
  }
  public A withResource(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource resource) {
    _visitables.get("resource").remove(this.resource);
    if (resource!=null){ this.resource= new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder(resource); _visitables.get("resource").add(this.resource);} return (A) this;
  }
  public java.lang.Boolean hasResource() {
    return this.resource != null;
  }
  public A withNewResource(java.lang.String group,java.lang.String resource) {
    return (A)withResource(new GroupResource(group, resource));
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> withNewResource() {
    return new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluentImpl.ResourceNestedImpl();
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> withNewResourceLike(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource item) {
    return new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluentImpl.ResourceNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> editResource() {
    return withNewResourceLike(getResource());
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> editOrNewResource() {
    return withNewResourceLike(getResource() != null ? getResource(): new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder().build());
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> editOrNewResourceLike(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource item) {
    return withNewResourceLike(getResource() != null ? getResource(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageStateSpecFluentImpl that = (StorageStateSpecFluentImpl) o;
    if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(resource,  additionalProperties,  super.hashCode());
  }
  public class ResourceNestedImpl<N> extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceFluentImpl<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<N>> implements io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ResourceNestedImpl(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource item) {
      this.builder = new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder(this, item);
    }
    ResourceNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder(this);
    }
    io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder builder;
    public N and() {
      return (N) StorageStateSpecFluentImpl.this.withResource(builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}

==> openshift-model-storageversionmigrator-5.12.1-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StorageStateSpecFluentImpl<A extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent<A>{
  public StorageStateSpecFluentImpl() {
  }
  public StorageStateSpecFluentImpl(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpec instance) {
    this.withResource(instance.getResource()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder resource;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource getResource() {
    return this.resource!=null?this.resource.build():null;
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource buildResource() {
    return this.resource!=null?this.resource.build():null;
  }
  public A withResource(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource resource) {
    _visitables.get("resource").remove(this.resource);
    if (resource!=null){ this.resource= new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder(resource); _visitables.get("resource").add(this.resource);} return (A) this;
  }
  public java.lang.Boolean hasResource() {
    return this.resource != null;
  }
  public A withNewResource(java.lang.String group,java.lang.String resource) {
    return (A)withResource(new GroupResource(group, resource));
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> withNewResource() {
    return new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluentImpl.ResourceNestedImpl();
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> withNewResourceLike(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource item) {
    return new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluentImpl.ResourceNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> editResource() {
    return withNewResourceLike(getResource());
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> editOrNewResource() {
    return withNewResourceLike(getResource() != null ? getResource(): new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder().build());
  }
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<A> editOrNewResourceLike(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource item) {
    return withNewResourceLike(getResource() != null ? getResource(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageStateSpecFluentImpl that = (StorageStateSpecFluentImpl) o;
    if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(resource,  additionalProperties,  super.hashCode());
  }
  public class ResourceNestedImpl<N> extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceFluentImpl<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<N>> implements io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateSpecFluent.ResourceNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ResourceNestedImpl(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResource item) {
      this.builder = new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder(this, item);
    }
    ResourceNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder(this);
    }
    io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.GroupResourceBuilder builder;
    public N and() {
      return (N) StorageStateSpecFluentImpl.this.withResource(builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}
